# Demo Notebooks

These notebooks provide tutorials for a variety of aspects of the `qp` code.

| Notebook                                            | Description                                                                | Download                             |
| --------------------------------------------------- | -------------------------------------------------------------------------- | ------------------------------------ |
| [Exploring `qp` Files](project:ensemble_file.md)    | Explores what is in a `qp` file and how to create one without an Ensemble. | {download}`ensemble_file.ipynb`      |
| [Conversion example](project:conversion_example.md) | Explores details of how to convert Ensembles between parameterizations.    | {download}`conversion_example.ipynb` |
| [Iterator Example](project:iterator_demo.md)        | Demonstrates how to iterate over a `qp` file.                              | {download}`iterator_demo.ipynb`      |

**Legacy Notebooks**

The following are legacy notebooks that work for `qp` version < 1. They are made available here for reference purposes.

| Notebook                                              | Description                                                            | Download                            |
| ----------------------------------------------------- | ---------------------------------------------------------------------- | ----------------------------------- |
| [Quantile Parameterization](project:quantile_demo.md) | How to use the quantile parameterization                               | {download}`quantile_demo.ipynb`     |
| [Demo Notebook](project:demo.md)                      | Tutorial on how qp distributions work and how to use them              | {download}`demo.ipynb`              |
| [Metrics Example](project:metrics_examples.md)        | Demonstrates how to calculate some metrics on a qp ensemble            | {download}`metrics_examples.ipynb`  |
| [Practical Example](project:practical_example.md)     | Demonstrates how to use Ensembles with real data (need access to SLAC) | {download}`practical_example.ipynb` |
| [Mixmod Example](project:metrics_examples.md)         | Tutorial on how the Gaussian mixture model parameterization works      | {download}`mixmod_examples.ipynb`   |

```{toctree}
:hidden:
:titlesonly:

Exploring qp Files <ensemble_file>
Conversion Example <conversion_example>
Iterator Example <iterator_demo>
Quantile Parameterization (legacy) <quantile_demo>
Demo Notebook (legacy) <demo>
Metrics Example (legacy) <metrics_examples>
Practical Example (legacy) <practical_example>
Mixmod Example (legacy) <mixmod_examples>
```
